# langchain-db2

This package contains the LangChain integration with the connector to Db2 vector store. This will allow user to leverage the vector store and vector search ablility of the IBM Db2 relational datebase.

## Installation

```bash
pip install -U langchain-db2
```

See more details of how to use it in the Jupyter Notebook: langchain-db2/docs/db2.ipynb (This link will be updated https://github.com/langchain-ai/langchain-ibm/blob/756f43fe392f70f6c4b755d7966ea8ee1cc42759/libs/langchain-db2/docs/db2.ipynb)

